==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/BuildSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class BuildSpecFluentImpl<A extends BuildSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BuildSpecFluent<A> {

    private List<TaskBuilder> tasks;

    public BuildSpecFluentImpl() {
    }

    public BuildSpecFluentImpl(BuildSpec instance) {
        this.withTasks(instance.getTasks()); 
    }

    public A addToTasks(int index,Task item) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(index >= 0 ? index : _visitables.get("tasks").size(), builder);this.tasks.add(index >= 0 ? index : tasks.size(), builder); return (A)this;
    }

    public A setToTasks(int index,Task item) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        TaskBuilder builder = new TaskBuilder(item);
        if (index < 0 || index >= _visitables.get("tasks").size()) { _visitables.get("tasks").add(builder); } else { _visitables.get("tasks").set(index, builder);}
        if (index < 0 || index >= tasks.size()) { tasks.add(builder); } else { tasks.set(index, builder);}
         return (A)this;
    }

    public A addToTasks(Task... items) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(builder);this.tasks.add(builder);} return (A)this;
    }

    public A addAllToTasks(Collection<Task> items) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(builder);this.tasks.add(builder);} return (A)this;
    }

    public A removeFromTasks(Task... items) {
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").remove(builder);if (this.tasks != null) {this.tasks.remove(builder);}} return (A)this;
    }

    public A removeAllFromTasks(Collection<Task> items) {
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").remove(builder);if (this.tasks != null) {this.tasks.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromTasks(Predicate<TaskBuilder> predicate) {
        if (tasks == null) return (A) this;
        final Iterator<TaskBuilder> each = tasks.iterator();
        final List visitables = _visitables.get("tasks");
        while (each.hasNext()) {
          TaskBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildTasks instead.
 * @return The buildable object.
 */
@Deprecated public List<Task> getTasks() {
        return build(tasks);
    }

    public List<Task> buildTasks() {
        return build(tasks);
    }

    public Task buildTask(int index) {
        return this.tasks.get(index).build();
    }

    public Task buildFirstTask() {
        return this.tasks.get(0).build();
    }

    public Task buildLastTask() {
        return this.tasks.get(tasks.size() - 1).build();
    }

    public Task buildMatchingTask(Predicate<TaskBuilder> predicate) {
        for (TaskBuilder item: tasks) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingTask(Predicate<TaskBuilder> predicate) {
        for (TaskBuilder item: tasks) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withTasks(List<Task> tasks) {
        if (this.tasks != null) { _visitables.get("tasks").removeAll(this.tasks);}
        if (tasks != null) {this.tasks = new ArrayList<TaskBuilder>(); for (Task item : tasks){this.addToTasks(item);}} else { this.tasks = null;} return (A) this;
    }

    public A withTasks(Task... tasks) {
        if (this.tasks != null) {this.tasks.clear();}
        if (tasks != null) {for (Task item :tasks){ this.addToTasks(item);}} return (A) this;
    }

    public Boolean hasTasks() {
        return tasks != null && !tasks.isEmpty();
    }

    public BuildSpecFluent.TasksNested<A> addNewTask() {
        return new TasksNestedImpl();
    }

    public BuildSpecFluent.TasksNested<A> addNewTaskLike(Task item) {
        return new TasksNestedImpl(-1, item);
    }

    public BuildSpecFluent.TasksNested<A> setNewTaskLike(int index,Task item) {
        return new TasksNestedImpl(index, item);
    }

    public BuildSpecFluent.TasksNested<A> editTask(int index) {
        if (tasks.size() <= index) throw new RuntimeException("Can't edit tasks. Index exceeds size.");
        return setNewTaskLike(index, buildTask(index));
    }

    public BuildSpecFluent.TasksNested<A> editFirstTask() {
        if (tasks.size() == 0) throw new RuntimeException("Can't edit first tasks. The list is empty.");
        return setNewTaskLike(0, buildTask(0));
    }

    public BuildSpecFluent.TasksNested<A> editLastTask() {
        int index = tasks.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last tasks. The list is empty.");
        return setNewTaskLike(index, buildTask(index));
    }

    public BuildSpecFluent.TasksNested<A> editMatchingTask(Predicate<TaskBuilder> predicate) {
        int index = -1;
        for (int i=0;i<tasks.size();i++) { 
        if (predicate.test(tasks.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching tasks. No match found.");
        return setNewTaskLike(index, buildTask(index));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        BuildSpecFluentImpl that = (BuildSpecFluentImpl) o;
        if (tasks != null ? !tasks.equals(that.tasks) :that.tasks != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(tasks,  super.hashCode());
    }

    public class TasksNestedImpl<N> extends TaskFluentImpl<BuildSpecFluent.TasksNested<N>> implements BuildSpecFluent.TasksNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final TaskBuilder builder;
        private final int index;

            TasksNestedImpl(int index,Task item) {
                this.index = index;
                this.builder = new TaskBuilder(this, item);
                        
            }

            TasksNestedImpl() {
                this.index = -1;
                this.builder = new TaskBuilder(this);
                        
            }

            public N and() {
                return (N) BuildSpecFluentImpl.this.setToTasks(index,builder.build());
            }

            public N endTask() {
                return and();
            }
    }


}

==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/BuildSpecFluentImpl.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class BuildSpecFluentImpl<A extends BuildSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements BuildSpecFluent<A> {

    private List<TaskBuilder> tasks;

    public BuildSpecFluentImpl() {
    }

    public BuildSpecFluentImpl(BuildSpec instance) {
        this.withTasks(instance.getTasks()); 
    }

    public A addToTasks(int index,Task item) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(index >= 0 ? index : _visitables.get("tasks").size(), builder);this.tasks.add(index >= 0 ? index : tasks.size(), builder); return (A)this;
    }

    public A setToTasks(int index,Task item) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        TaskBuilder builder = new TaskBuilder(item);
        if (index < 0 || index >= _visitables.get("tasks").size()) { _visitables.get("tasks").add(builder); } else { _visitables.get("tasks").set(index, builder);}
        if (index < 0 || index >= tasks.size()) { tasks.add(builder); } else { tasks.set(index, builder);}
         return (A)this;
    }

    public A addToTasks(Task... items) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(builder);this.tasks.add(builder);} return (A)this;
    }

    public A addAllToTasks(Collection<Task> items) {
        if (this.tasks == null) {this.tasks = new ArrayList<TaskBuilder>();}
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").add(builder);this.tasks.add(builder);} return (A)this;
    }

    public A removeFromTasks(Task... items) {
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").remove(builder);if (this.tasks != null) {this.tasks.remove(builder);}} return (A)this;
    }

    public A removeAllFromTasks(Collection<Task> items) {
        for (Task item : items) {TaskBuilder builder = new TaskBuilder(item);_visitables.get("tasks").remove(builder);if (this.tasks != null) {this.tasks.remove(builder);}} return (A)this;
    }

    public A removeMatchingFromTasks(Predicate<TaskBuilder> predicate) {
        if (tasks == null) return (A) this;
        final Iterator<TaskBuilder> each = tasks.iterator();
        final List visitables = _visitables.get("tasks");
        while (each.hasNext()) {
          TaskBuilder builder = each.next();
          if (predicate.test(builder)) {
            visitables.remove(builder);
            each.remove();
          }
        }
        return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildTasks instead.
 * @return The buildable object.
 */
@Deprecated public List<Task> getTasks() {
        return build(tasks);
    }

    public List<Task> buildTasks() {
        return build(tasks);
    }

    public Task buildTask(int index) {
        return this.tasks.get(index).build();
    }

    public Task buildFirstTask() {
        return this.tasks.get(0).build();
    }

    public Task buildLastTask() {
        return this.tasks.get(tasks.size() - 1).build();
    }

    public Task buildMatchingTask(Predicate<TaskBuilder> predicate) {
        for (TaskBuilder item: tasks) { if(predicate.test(item)){ return item.build();} } return null;
    }

    public Boolean hasMatchingTask(Predicate<TaskBuilder> predicate) {
        for (TaskBuilder item: tasks) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withTasks(List<Task> tasks) {
        if (this.tasks != null) { _visitables.get("tasks").removeAll(this.tasks);}
        if (tasks != null) {this.tasks = new ArrayList<TaskBuilder>(); for (Task item : tasks){this.addToTasks(item);}} else { this.tasks = null;} return (A) this;
    }

    public A withTasks(Task... tasks) {
        if (this.tasks != null) {this.tasks.clear();}
        if (tasks != null) {for (Task item :tasks){ this.addToTasks(item);}} return (A) this;
    }

    public Boolean hasTasks() {
        return tasks != null && !tasks.isEmpty();
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> addNewTask() {
        return new TasksNestedImpl();
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> addNewTaskLike(Task item) {
        return new TasksNestedImpl(-1, item);
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> setNewTaskLike(int index,Task item) {
        return new TasksNestedImpl(index, item);
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> editTask(int index) {
        if (tasks.size() <= index) throw new RuntimeException("Can't edit tasks. Index exceeds size.");
        return setNewTaskLike(index, buildTask(index));
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> editFirstTask() {
        if (tasks.size() == 0) throw new RuntimeException("Can't edit first tasks. The list is empty.");
        return setNewTaskLike(0, buildTask(0));
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> editLastTask() {
        int index = tasks.size() - 1;
        if (index < 0) throw new RuntimeException("Can't edit last tasks. The list is empty.");
        return setNewTaskLike(index, buildTask(index));
    }

    public io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<A> editMatchingTask(Predicate<TaskBuilder> predicate) {
        int index = -1;
        for (int i=0;i<tasks.size();i++) { 
        if (predicate.test(tasks.get(i))) {index = i; break;}
        } 
        if (index < 0) throw new RuntimeException("Can't edit matching tasks. No match found.");
        return setNewTaskLike(index, buildTask(index));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        BuildSpecFluentImpl that = (BuildSpecFluentImpl) o;
        if (tasks != null ? !tasks.equals(that.tasks) :that.tasks != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(tasks,  super.hashCode());
    }

    public class TasksNestedImpl<N> extends TaskFluentImpl<io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<N>> implements io.fabric8.camelk.v1.BuildSpecFluent.TasksNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final TaskBuilder builder;
        private final int index;

            TasksNestedImpl(int index,Task item) {
                this.index = index;
                this.builder = new TaskBuilder(this, item);
                        
            }

            TasksNestedImpl() {
                this.index = -1;
                this.builder = new TaskBuilder(this);
                        
            }

            public N and() {
                return (N) BuildSpecFluentImpl.this.setToTasks(index,builder.build());
            }

            public N endTask() {
                return and();
            }
    }


}
